@@ -18,6 +18,7 @@
 #include <sys/select.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <sys/un.h>
 #include <malloc.h>
 #include <syslog.h>
@@ -187,7 +188,7 @@ static void parse_wpa_event(const char *msg, enum wpaevent *ev, char *idstr)
     pos = strstr(pos, "id_str=");
     if(pos != NULL) {
       pos += strlen("id_str=");
-      pos2 = index(pos, ']');
+      pos2 = rindex(pos, ']');
       strncpy(idstr, pos, min(pos2-pos, IDSTRLEN-1));
       idstr[min(pos2-pos, IDSTRLEN-1)] = '\0';
     }
